import os
import pymysql
import pandas as pd

def connect(dbname: str, cluster: str = 'analytics') -> pymysql.connections.Connection:
    if cluster not in ['analytics', 'web']:
        raise ValueError('"cluster" must be one of: "analytics", "web"')

    if dbname.endswith('_p'):
        dbname = dbname[:-2]
    return pymysql.connect(
        host="{dbname}.{cluster}.db.svc.wikimedia.cloud".format(dbname=dbname, cluster=cluster),
        read_default_file=os.path.expanduser("~/.my.cnf"),
        database="{dbname}_p".format(dbname=dbname),
        charset='utf8'
    )

def run_sql(query: str, dbname: str, cluster: str = 'analytics'):
    df = pd.read_sql_query(query, connect(dbname, cluster))
    for x in df:
        df[x] = df[x].apply(lambda y: y.decode('utf-8') if isinstance(y, bytes) else y)
    return df



"""
wmpaws
-------------

This is the description for that library
"""
from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='wmpaws',
    version='0.1',
    license='GNU',
    author='Martin Urbanec',
    author_email='martin@urbanec.cz',
    description='To be done',
    long_description=long_description,
    long_description_content_type='text/markdown',
    py_modules=['wmpaws'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[
        'pymysql',
        'pandas'
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
